@@ -364,6 +364,7 @@ class MarklogicApiClient:
         date_from=None,
         date_to=None,
         page=1,
+        page_size=RESULTS_PER_PAGE,
         show_unpublished=False,
         only_unpublished=False
     ) -> requests.Response:
@@ -380,6 +381,7 @@ class MarklogicApiClient:
         :param date_from:
         :param date_to:
         :param page:
+        :param page_size:
         :param show_unpublished: If True, both published and unpublished documents will be returned
         :param only_unpublished: If True, will only return published documents. Ignores the value of show_unpublished
         :return:
@@ -389,7 +391,7 @@ class MarklogicApiClient:
             "court": str(court or ""),
             "judge": str(judge or ""),
             "page": page,
-            "page-size": RESULTS_PER_PAGE,
+            "page-size": int(page_size),
             "q": str(q or ""),
             "party": str(party or ""),
             "neutral_citation": str(neutral_citation or ""),
@@ -403,7 +405,7 @@ class MarklogicApiClient:
 
         return self.invoke(module, vars)
 
-    def eval_xslt(self, judgment_uri, version_uri=None, show_unpublished=False) -> requests.Response:
+    def eval_xslt(self, judgment_uri, version_uri=None, show_unpublished=False, xsl_filename="judgment2.xsl") -> requests.Response:
         uri = f"/{judgment_uri.lstrip('/')}.xml"
         if version_uri:
             version_uri = f"/{version_uri.lstrip('/')}.xml"
@@ -417,10 +419,17 @@ class MarklogicApiClient:
             "uri": uri,
             "version_uri": version_uri,
             "show_unpublished": str(show_unpublished).lower(),
-            "img_location": image_location
+            "img_location": image_location,
+            "xsl_filename": xsl_filename
         })
         return self.eval(xquery_path, vars=vars, accept_header="application/xml")
 
+    def accessible_judgment_transformation(self, judgment_uri, version_uri=None, show_unpublished=False):
+        return self.eval_xslt(judgment_uri, version_uri, show_unpublished, xsl_filename="judgment2.xsl")
+
+    def original_judgment_transformation(self, judgment_uri, version_uri=None, show_unpublished=False):
+        return self.eval_xslt(judgment_uri, version_uri, show_unpublished, xsl_filename="judgment0.xsl")
+
     def get_property(self, judgment_uri, name):
         uri = self._format_uri(judgment_uri)
         xquery_path = os.path.join(
@@ -537,6 +546,23 @@ class MarklogicApiClient:
             accept_header="application/xml",
         )
 
+    def copy_judgment(self, old, new):
+        old_uri = self._format_uri(old)
+        new_uri = self._format_uri(new)
+
+        xquery_path = os.path.join(
+            ROOT_DIR, "xquery", "copy_judgment.xqy"
+        )
+        vars = json.dumps({
+            "old_uri": old_uri,
+            "new_uri": new_uri,
+        })
+        return self.eval(
+            xquery_path,
+            vars=vars,
+            accept_header="application/xml",
+        )
+
 
 api_client = MarklogicApiClient(
     host=env("MARKLOGIC_HOST"),
